==> lightbox_tobii-1.0.1.tar.gz: lightbox_tobii/src/Plugin/Field/FieldFormatter/LightboxTobiiFormatter.php <==
<?php

namespace Drupal\lightbox_tobii\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Crypt;
use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lightbox\Plugin\Field\FieldFormatter\LightboxImageFormatter;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'lightbox_tobii' formatter.
 */
#[FieldFormatter(
  id: 'lightbox_tobii',
  label: new TranslatableMarkup('Lightbox image with Tobii'),
  field_types: [
    'image',
  ],
)]
class LightboxTobiiFormatter extends LightboxImageFormatter {

  use LightboxTobiiFormatterTrait;

  /**
   * The constructor method.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->configFactory = $container->get('config.factory');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);

    // Allow grouping images of a multivalued field in one Tobii gallery.
    $default_group_id = 'tobii--' . Crypt::randomBytesBase64(4);
    foreach ($elements as $delta => $element) {
      $elements[$delta]['#attributes']['data-lightbox-group'] = $default_group_id;
    }

    $this->attachLibraryAndGlobalSettings($elements);

    return $elements;
  }

}

==> lightbox_tobii-1.2.0.tar.gz: lightbox_tobii/src/Plugin/Field/FieldFormatter/LightboxTobiiFormatter.php <==
<?php

namespace Drupal\lightbox_tobii\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Crypt;
use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lightbox\Plugin\Field\FieldFormatter\LightboxImageFormatter;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'lightbox_tobii' formatter.
 */
#[FieldFormatter(
  id: 'lightbox_tobii',
  label: new TranslatableMarkup('Lightbox image with Tobii'),
  field_types: [
    'image',
  ],
)]
class LightboxTobiiFormatter extends LightboxImageFormatter {

  use LightboxTobiiFormatterTrait;

  /**
   * The constructor method.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->configFactory = $container->get('config.factory');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);

    $configuration_id = $this->getConfigurationId();
    // Allow grouping images of a multivalued field in one Tobii gallery.
    $default_group_id = 'tobii--' . Crypt::randomBytesBase64(4);
    foreach ($elements as $delta => $element) {
      $elements[$delta]['#attributes']['data-lightbox-conf'] = $configuration_id;
      $elements[$delta]['#attributes']['data-lightbox-group'] = $default_group_id;
    }

    $this->attachLibraryAndSettings($elements);

    return $elements;
  }

}
